@@ -2,8 +2,8 @@ import os
 
 import yaml
 
-from ..utils.dicts import update_dict
 from ..config.mapping import config_map
+from ..utils.dicts import update_dict
 
 _settings = None
 
@@ -26,7 +26,7 @@ def get_settings(reload=False, file="~/.machinable/settings.yaml"):
                     "cache": {"imports": False},
                     "imports": {},
                     "tmp_directory": "userdata://machinable:machinable/tmp",
-                    "default_storage": "mem://",
+                    "default_storage": {"url": "mem://"},
                     "default_engine": None,
                     "default_index": None,
                 },
