@@ -6,11 +6,15 @@ class DryEngine(Engine):
         Engine.set_latest(self)
 
     def __repr__(self):
-        return "Dry run"
+        return "Engine <dry>"
 
     @staticmethod
     def supports_resources():
         return False
 
+    def storage_middleware(self, storage):
+        storage["url"] = "mem://"
+        return storage
+
     def _submit(self, execution):
         return execution
