@@ -7,6 +7,7 @@ import sh
 
 from ..core.exceptions import ExecutionException
 from ..filesystem import open_fs
+from ..utils.formatting import exception_to_str
 from .engine import Engine
 
 
@@ -104,7 +105,7 @@ class SlurmEngine(Engine):
             component_id = component["flags"]["COMPONENT_ID"]
             script = f"{self.script}\n"
             script += f'#SBATCH --job-name="{execution.experiment_id}:{component_id}"\n'
-            script += f"#SBATCH -o {os.path.join(script_url.replace('osfs://', ''), component_id + '.out')}\n"
+            script += f"#SBATCH -o {os.path.join(url.replace('osfs://', ''), component_id,  'output.log')}\n"
             script += f"export MACHINABLE_PROJECT={execution.project.directory_path}\n"
             try:
                 script += self.commands["before_script"] + ";\n"
@@ -155,14 +156,19 @@ class SlurmEngine(Engine):
             # submit to slurm
             try:
                 p = sh.sbatch(*command)
-                execution.set_result(p)
-            except sh.ErrorReturnCode as ex:
+                execution.set_result(p, echo=False)
+            except Exception as ex:
+                if isinstance(ex, sh.ErrorReturnCode):
+                    message = ex.stderr.decode("utf-8")
+                else:
+                    message = exception_to_str(ex)
                 execution.set_result(
-                    ExecutionException(
-                        ex.stderr.decode("utf-8"), reason="engine_failure"
-                    )
+                    ExecutionException(message, reason="engine_failure"), echo=True,
                 )
-                self.log(f"Execution failed: {str(ex)}", level="error")
+
+        total = len(execution.schedule._result)
+        success = len(execution.schedule._result) - execution.failures
+        self.log(f"Submitted {success}/{total} jobs successfully")
 
         return execution
 
@@ -171,8 +177,9 @@ class SlurmEngine(Engine):
             raise ValueError("Remote engine does not support temporary file systems")
 
         storage["allow_overwrites"] = True
+        storage["output_redirection"] = "DISABLED"  # use slurm log instead
 
         return storage
 
     def __repr__(self):
-        return f"Slurm"
+        return f"Engine <slurm>"
