@@ -1,17 +1,17 @@
 import ast
-import os
 import inspect
+import os
 from datetime import datetime as dt
 from typing import Any, Callable, Union
 
 import pendulum
 import yaml
-
 from expandvars import expand
+
 from ..config.interface import ConfigInterface, mapped_config
+from ..config.mapping import config_map
 from ..core.exceptions import ExecutionException
 from ..core.settings import get_settings
-from ..config.mapping import config_map
 from ..engine import Engine
 from ..execution.schedule import Schedule
 from ..experiment.experiment import Experiment
@@ -273,6 +273,7 @@ class Execution(Jsonable):
         if len(unknown_options) > 0:
             raise ValueError(f"Invalid options: {unknown_options}")
         self._behavior.update(settings)
+        return self
 
     def is_submitted(self):
         try:
@@ -291,17 +292,26 @@ class Execution(Jsonable):
         self.failures = 0
         self.storage.config["experiment"] = self.experiment_id
 
+        # auto-name experiment if imported via @ directive
+        if self.experiment.specification["name"] is None:
+            if hasattr(self.experiment, "_resolved_module_name"):
+                self.experiment.name(self.experiment._resolved_module_name)
+
         # expand variables in storage directory
         if isinstance(self.storage.config["directory"], str):
             # % variables
             variables = dict()
-            try:
-                variables["PROJECT"] = self.project.name if self.project else None
-            except (KeyError, ValueError):
-                variables["PROJECT"] = None
+
+            variables["PROJECT"] = (
+                self.project.name.replace(".", "/")
+                if self.project.name is not None
+                else None
+            )
 
             variables["EXPERIMENT"] = (
-                self.experiment.specification["name"] if self.experiment else ""
+                self.experiment.specification["name"].replace(".", "/")
+                if self.experiment.specification["name"] is not None
+                else ""
             )
 
             self.storage.config["directory"] = expand(
@@ -392,29 +402,39 @@ class Execution(Jsonable):
 
             self.index.add(StorageExperiment(url, data))
 
+            msg(
+                f"{self.experiment_id} <{url}> ({self.started_at})\n",
+                level="info",
+                color="header",
+            )
+
         Registration.get().on_submit(self, is_submitted)
 
         return self.engine.submit(self)
 
-    def set_result(self, result, index=None):
+    def set_result(self, result, index=None, echo=True):
         if index is None:
             index = len(self.schedule._result)
         if isinstance(result, ExecutionException):
             self.failures += 1
             if self._behavior["raise_exceptions"]:
                 raise result
-            self.engine.log(
-                f"Submission {self.components[index]} of experiment {self.experiment_id} failed "
-                f"({index + 1}/{len(self.schedule)}). "
-                f"{exception_to_str(result)}",
-                level="error",
-            )
+            if echo or echo == "success":
+                msg(
+                    f"\nComponent <{self.components[index]}> of experiment {self.experiment_id} failed "
+                    f"({index + 1}/{len(self.schedule)})\n"
+                    f"{exception_to_str(result)}",
+                    level="error",
+                    color="header",
+                )
         else:
-            self.engine.log(
-                f"Submission {self.components[index]} of experiment {self.experiment_id} complete "
-                f"({index + 1}/{len(self.schedule)}). ",
-                level="info",
-            )
+            if echo or echo == "failure":
+                msg(
+                    f"\nComponent <{self.components[index]}> of experiment {self.experiment_id} completed "
+                    f"({index + 1}/{len(self.schedule)})\n",
+                    level="info",
+                    color="header",
+                )
         self.schedule.set_result(result, index)
 
     @classmethod
@@ -539,6 +559,10 @@ class Execution(Jsonable):
             "timestamp": self.timestamp,
             "started_at": self.started_at,
             "components": self.components,
+            "project_name": self.project.name if self.project is not None else None,
+            "experiment_name": self.experiment.specification["name"]
+            if self.experiment is not None
+            else None,
         }
 
     @classmethod
@@ -564,14 +588,39 @@ class Execution(Jsonable):
             self.set_schedule()
 
         msg(
-            f"\nExecution: {self.experiment_id}\n----------", color="header",
+            f"\n{self.experiment_id}\n------", color="header",
         )
         msg(
-            f"Storage: {self.storage}", color="blue",
+            f"{repr(self.experiment)}", color="blue",
         )
-        msg(f"Engine: {repr(self.engine)}", color="blue")
-        msg(f"Index: {repr(self.index)}", color="blue")
-        msg(f"Project: {repr(self.project)}", color="blue")
+        msg(
+            f"{repr(self.storage)}", color="blue",
+        )
+        msg(f"{repr(self.engine)}", color="blue")
+        msg(f"{repr(self.index)}", color="blue")
+        msg(f"{repr(self.project)}", color="blue")
+        msg(f"Seed <{self.seed}>", color="blue")
+
+        def _flags(flags):
+            filtered = {
+                k: v
+                for k, v in flags.items()
+                if k
+                not in {
+                    "GLOBAL_SEED",
+                    "EXPERIMENT_ID",
+                    "SEED",
+                    "COMPONENT_ID",
+                    "REPEAT_SEED",
+                    "REPEAT_TOTAL",
+                    "REPEAT_NUMBER",
+                    "NAME",
+                    "MODULE",
+                }
+            }
+            if len(filtered) == 0:
+                return ""
+            return yaml.dump(filtered, default_flow_style=False)
 
         for (
             index,
@@ -582,29 +631,32 @@ class Execution(Jsonable):
             if shortened:
                 if index == 1:
                     msg(
-                        f"[ + {len(self.schedule) - 2} other experiments ]",
+                        f"[ + {len(self.schedule) - 2} other components ]",
                         color="header",
                     )
                 continue
 
             msg(
-                f"\n{self.components[index]} ({index + 1}/{len(self.schedule)})",
-                color="header",
+                f"\nComponent: {component['name']} <{self.components[index]}> ({index + 1}/{len(self.schedule)})",
+                color="green",
             )
 
-            msg(f"\nComponent: {component['name']}", color="yellow")
-            msg(f":: {component['flags']}")
             if len(component["versions"]) > 0:
                 msg(f">> {', '.join(component['versions'])}", color="green")
-            msg(yaml.dump(component["args"]), color="blue")
+            msg(_flags(component["flags"]))
+            msg(yaml.dump(component["args"], default_flow_style=False), color="blue")
 
             for c in components:
                 if c:
-                    msg(f"\t {c['name']}", color="yellow")
-                    msg(f"\t:: {c['flags']}")
+                    msg(f"\t{c['name']}", color="yellow")
                     if len(c["versions"]) > 0:
                         msg(f"\t>> {', '.join(c['versions'])}", color="green")
-                    msg("\t" + yaml.dump(c["args"]), color="blue")
+                    msg(_flags(c["flags"]))
+                    msg(
+                        yaml.dump(c["args"], default_flow_style=False), color="blue",
+                    )
+
+        msg("------\n", color="header")
 
         return self
 
