@@ -64,6 +64,16 @@ class StorageExperiment:
         """6-digit experiment ID, e.g. F4K3r6"""
         return self.file("execution.json")["experiment_id"]
 
+    @property
+    def experiment_name(self) -> Optional[str]:
+        """Experiment name"""
+        return self.file("execution.json")["experiment_name"]
+
+    @property
+    def project_name(self) -> Optional[str]:
+        """Project name"""
+        return self.file("execution.json")["project_name"]
+
     @property
     def seed(self) -> int:
         """Returns the global random seed used in the experiment"""
@@ -195,4 +205,4 @@ class StorageExperiment:
         return self.__repr__()
 
     def __repr__(self):
-        return f"Storage: Experiment <{self.experiment_id}>"
+        return f"StorageExperiment <{self.experiment_id}>"
