@@ -9,11 +9,9 @@ def resolve_instance(arg, instance_type, default_path=""):
         return None
 
     if arg.startswith("@/"):
-        origin = None
         module_name = arg.replace("@/", "")
     else:
         # if relative path @example insert default path
-        origin = arg[1:].replace(".", "/")
         module_name = arg.replace("@", os.path.join(default_path, ""), 1)
 
     module_name = module_name.replace("/", ".")
@@ -27,8 +25,7 @@ def resolve_instance(arg, instance_type, default_path=""):
         instance = instance_type.latest()
         if isinstance(instance, instance_type):
             instance._resolved_by_expression = arg
-            if origin:
-                instance._resolved_module_origin = origin
+            instance._resolved_module_name = module_name
             return instance
 
         raise ValueError(
@@ -39,3 +36,20 @@ def resolve_instance(arg, instance_type, default_path=""):
             f"Could not import module @{module_name} "
             f"The following exception occurred: {exception_to_str(e)}. "
         )
+
+
+def resolve_instance_from_code(code, instance_type):
+    try:
+        instance_type.set_latest(None)
+        exec(code)
+
+        instance = instance_type.latest()
+        if isinstance(instance, instance_type):
+            instance._resolved_by_code = code
+            return instance
+
+        raise ValueError(f"Could not find any {instance_type.__name__} in code")
+    except Exception as e:
+        raise ImportError(
+            f"Could not evaluate code. The following exception occurred: {exception_to_str(e)}. "
+        )
