@@ -1,4 +1,5 @@
 import os
+
 from machinable.index.sql_index import SqlIndex
 
 
@@ -9,4 +10,9 @@ def test_sql_index(helpers):
     index = SqlIndex(database)
     assert index.find("tttttt") is None
     index.add("./_test_data/storage/tttttt")
-    assert index.find("tttttt").id == "tttttt"
+    assert index.find("tttttt").experiment_id == "tttttt"
+    latest = index.find_latest()
+    assert len(latest) > 0
+    since = latest.first().started_at
+    experiments = index.find_latest(since=since)
+    assert len(experiments) == 0
